<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package yeti
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function yeti_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

    //Header Layout
    $header_layout = cs_get_option('header_layout','layout1');
    $classes[] = 'header-'.$header_layout;

    //Sticky Header
    $sticky_header = cs_get_option('yeti_sticky_header');
    if($sticky_header == 1){
        $classes[] = 'is-sticky';
    }

    //Transparent header
    $meta = get_post_meta(get_the_ID(),'_custom_meta',true);
    $is_trans = isset($meta['header_transparent']) ? $meta['header_transparent'] : '';
    if($is_trans!='' && $header_layout == 'layout2'){
        $classes[] = 'is-trans';
    }

    $blog_transparent = cs_get_option('blog_header_transparent');
    if( $blog_transparent != '' && (is_home() || is_post_type_archive('post') )){
        $classes[] = 'is-trans';
    }

    $archive_layout = cs_get_option('blog_layout','list');
    $archive_layout_page = isset($meta['blog_page_layout']) ? $meta['blog_page_layout'] : 'list';
    if(($archive_layout == 'grid' && (is_home() || is_post_type_archive('post'))) || (is_page() && $archive_layout_page == 'grid')){
        $classes[] = 'grid-layout';
    }

    if(is_singular('post')){
        $posts_layout = cs_get_option('single_post_layout','full');
        if($posts_layout == 'full'){
            $classes[] = 'is-trans';
        }
    }

	return $classes;
}
add_filter( 'body_class', 'yeti_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function yeti_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'yeti_pingback_header' );

/** ============================================================
** Yeti Theme Functions 
**===============================================================*/
function yeti_site_logo(){
    $logo = cs_get_option('default-logo');
    $high_logo = cs_get_option( 'retina-logo' );
    if( $logo || $high_logo ) :
        $logo_img = wp_get_attachment_image_src( $logo, 'full' );
        $high_res = wp_get_attachment_image_src( $high_logo, 'full' );
        ?>

        <a class="logo" href="<?php echo esc_url( home_url('/') ); ?>">
            <img src="<?php echo esc_url( $logo_img[0] ); ?>" alt="<?php bloginfo('name'); ?>">
        </a>

        <?php if($high_res[0]): ?>
            <a class="logo high-res" href="<?php echo esc_url( home_url('/') ); ?>">
                <img src="<?php echo esc_url( $high_res[0] ); ?>" alt="<?php esc_attr( bloginfo('name' ) ); ?>">
            </a>
        <?php endif; ?>
        <?php
        else:
            ?>
            <h1 id="logo">
                <a class="navbar-brand" href="<?php echo esc_url( home_url('/') ) ?>">
                    <?php esc_html( bloginfo('name') ); ?>
                </a>
            </h1>
            <?php
        endif;
}

function yeti_social_icons(){
    $yeti_social_icons = cs_get_option('yeti_social_icons');
    if($yeti_social_icons!=''):
	?>
    <ul class="social-icons">
	    <?php
		foreach($yeti_social_icons as $social_icons){
	        $social_title = $social_icons['yeti_social_title'];
	        $social_link = $social_icons['yeti_social_link'];
	        $social_icon = $social_icons['yeti_social_icon']; 

	        if($social_link && $social_icon){
	        	echo '<li class="'.esc_attr($social_title).'">';
	        	echo '<a href="'.esc_url($social_link).'" title="'.esc_attr($social_title).'"><i class="'.esc_attr($social_icon).'"></i></a>';
	        	echo '</li>';
	        }
		}
	    ?>
    </ul>
	<?php
	endif;
}

function yeti_related_posts($perpage){
    $excerpt = 20;
    $read_more = cs_get_option('read_more_text','Read more');
    $related_args = array( 
        'post_type' => 'post', 
        'post_status' => 'publish',
        'posts_per_page' => $perpage,
        'orderby' => 'rand',
        'post__not_in' => array( get_the_ID() ),
    );
    $categories = get_the_category( get_the_ID() );
    if ( $categories ) {
        $category_ids = array();
        foreach( $categories as $individual_category ) {
            $category_ids[] = $individual_category->term_id;
        }
        $related_args['category__in'] = $category_ids;
    }
    wp_reset_postdata();
    $related_query = new WP_Query( $related_args );
    if( $related_query->have_posts() ) {
        ?>
        <section class="related-articals section-padding">
            <h2 class="main-title"> <?php esc_html_e('Related Articles','yeti'); ?></h2>
            <div class="row">
            <?php
            while( $related_query->have_posts() ) {
                $related_query->the_post();
                $image_id = get_post_thumbnail_id();
                $single_layout = cs_get_option('single_post_layout','full');
                if($single_layout == 'full'){
                    $image_size = 'yeti-blog-full';
                }else{
                    $image_size = 'yeti-blog-el2';
                }
                $image_path = wp_get_attachment_image_src( $image_id, $image_size, true );
                $image_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
                $col = 12/$perpage;
                $class = '';
                if(!has_post_thumbnail()){
                    $class = 'no-image';
                }
                ?>
                <div class="col-md-<?php echo esc_attr($col);?> col-sm-<?php echo esc_attr($col);?> col-xs-12 <?php echo esc_attr($class);?>">
                    <?php if(has_post_thumbnail()){?>
                    <figure>
                        <a href="<?php the_permalink();?>">
                            <img src="<?php echo esc_url($image_path[0]);?>" alt="<?php echo esc_attr($image_alt)?>">
                        </a>
                        <figcaption>
                            <?php the_category();?>
                        </figcaption>
                    </figure>
                    <?php }?>
                    <?php 
                    if(!has_post_thumbnail()){
                      the_category();
                    }
                    ?>
                    <h4>
                        <a href="<?php the_permalink();?>"><?php the_title();?></a>
                    </h4>
                    <?php yeti_entry_meta();?>
                    
                </div>
                <?php
            }
            wp_reset_postdata();       
            ?>
            </div>
        </section>
        <!--Related Posts -->
        <?php 
    }
}

/* Gutenberg Disable */

if(class_exists('CS_VERSION')){
    $gutenberg_enable = cs_get_option('gutenberg_enable');
}else{
    $gutenberg_enable = 'true';
}
if($gutenberg_enable == ''){

    add_filter('use_block_editor_for_post', '__return_false', 10);

    add_filter('use_block_editor_for_post_type', '__return_false', 10);
}
